AnalysisResults_names: Names of a Analysis Results Object
Description
Function to get the names of an AnalysisResults object.
Usage
# S3 method for AnalysisResults
names(x)
Value
Returns a character vector containing the names of the AnalysisResults object.
Arguments
- x
An AnalysisResults object created by getAnalysisResults.
Details
Returns the names of an analysis results that can be accessed by the user.