dataEnrichmentRates: Enrichment Dataset of Rates

dataEnrichmentRatesR Documentation

Enrichment Dataset of Rates

Description

A dataset containing the sample sizes and events of two groups. Use getDataset(dataEnrichmentRates) to create a dataset object that can be processed by getAnalysisResults().

Usage

dataEnrichmentRates

Format

A data.frame object.


rpact documentation built on March 4, 2026, 5:06 p.m.