dataEnrichmentRatesStratified: Stratified Enrichment Dataset of Rates

dataEnrichmentRatesStratifiedR Documentation

Stratified Enrichment Dataset of Rates

Description

A dataset containing the sample sizes and events of two groups. Use getDataset(dataEnrichmentRatesStratified) to create a dataset object that can be processed by getAnalysisResults().

Usage

dataEnrichmentRatesStratified

Format

A data.frame object.


rpact documentation built on March 4, 2026, 5:06 p.m.