getTestLabel: Get Test Label

View source: R/f_core_utilities.R

getTestLabelR Documentation

Get Test Label

Description

Returns a string representation of the input value for use as a test label. Handles various types, including NULL, NA, vectors, and custom objects.

Usage

getTestLabel(x)

Arguments

x

The value to be converted into a test label.

Value

A character string representing the input value.

Examples

## Not run: 
getTestLabel(NULL)
getTestLabel(NA)
getTestLabel(1:3)
getTestLabel(6)
getTestLabel(getDesignFisher())

## End(Not run)


rpact documentation built on March 4, 2026, 5:06 p.m.