names.StageResults: Names of a Stage Results Object

View source: R/class_analysis_stage_results.R

names.StageResultsR Documentation

Names of a Stage Results Object

Description

Function to get the names of a StageResults object.

Usage

## S3 method for class 'StageResults'
names(x)

Arguments

x

A StageResults object.

Details

Returns the names of stage results that can be accessed by the user.

Value

Returns a character vector containing the names of the AnalysisResults object.


rpact documentation built on March 4, 2026, 5:06 p.m.