param_design_with_default: Parameter Description: Design with Default

param_design_with_defaultR Documentation

Parameter Description: Design with Default

Description

Parameter Description: Design with Default

Arguments

design

The trial design. If no trial design is specified, a fixed sample size design is used. In this case, Type I error rate alpha, Type II error rate beta, twoSidedPower, and sided can be directly entered as argument where necessary.


rpact documentation built on March 4, 2026, 5:06 p.m.