param_lambda_counts: Parameter Description: lambda for Counts

param_lambda_countsR Documentation

Parameter Description: lambda for Counts

Description

Parameter Description: lambda for Counts

Arguments

lambda

A numeric value or vector that represents the assumed rate of a homogeneous Poisson process in the pooled treatment groups, there is no default.


rpact documentation built on March 4, 2026, 5:06 p.m.