param_maxNumberOfSubjects: Parameter Description: Maximum Number Of Subjects

param_maxNumberOfSubjectsR Documentation

Parameter Description: Maximum Number Of Subjects

Description

Parameter Description: Maximum Number Of Subjects

Arguments

maxNumberOfSubjects

maxNumberOfSubjects > 0 needs to be specified for power calculations or calculation of necessary follow-up (count data). For two treatment arms, it is the maximum number of subjects for both treatment arms.


rpact documentation built on March 4, 2026, 5:06 p.m.