param_slope: Parameter Description: Slope

param_slopeR Documentation

Parameter Description: Slope

Description

Parameter Description: Slope

Arguments

slope

If typeOfShape = "sigmoidEmax" is selected, slope can be entered to specify the slope of the sigmoid Emax model, default is 1.


rpact documentation built on March 4, 2026, 5:06 p.m.