param_three_dots_plot: Parameter Description: "..." (optional plot arguments)

param_three_dots_plotR Documentation

Parameter Description: "..." (optional plot arguments)

Description

Parameter Description: "..." (optional plot arguments)

Arguments

...

Optional plot arguments. At the moment xlim and ylim are implemented for changing x or y axis limits without dropping data observations.


rpact documentation built on March 4, 2026, 5:06 p.m.