A class for simulation results survival.
maxNumberOfIterationsThe number of simulation iterations. Is a numeric vector of length 1 containing a whole number.
seedThe seed used for random number generation. Is a numeric vector of length 1.
allocationRatioPlannedThe planned allocation ratio (n1 / n2) for the groups. For multi-arm designs, it is the allocation ratio relating the active arm(s) to the control. Is a positive numeric vector of length 1.
conditionalPowerThe conditional power at each stage of the trial. Is a numeric vector of length 1 containing a value between 0 and 1.
iterationsThe number of iterations used for simulations. Is a numeric vector of length 1 containing a whole number.
futilityPerStageThe per-stage probabilities of stopping the trial for futility. Is a numeric matrix.
futilityStopIn simulation results data set: indicates whether trial is stopped for futility or not.
directionUpperSpecifies the direction of the alternative, only applicable for one-sided testing. Default is TRUE which means that larger values of the test statistics yield smaller p-values. Is a logical vector of length 1.
plannedEventsDetermines the number of cumulated (overall) events in survival designs when the interim stages are planned. For two treatment arms, is the number of events for both treatment arms. For multi-arm designs, refers to the overall number of events for the selected arms plus control. Is a numeric vector of length kMax containing whole numbers.
minNumberOfEventsPerStageDetermines the minimum number of events per stage for data-driven sample size recalculation. Is a numeric vector of length kMax containing whole numbers.
maxNumberOfEventsPerStageDetermines the maximum number of events per stage for data-driven sample size recalculation. Is a numeric vector of length kMax containing whole numbers.
thetaH1The assumed effect under the alternative hypothesis. For survival designs, refers to the hazard ratio. Is a numeric vector.
calcEventsFunctionAn optional function that can be entered to define how event size is recalculated. By default, recalculation is performed with conditional power with specified minNumberOfEventsPerStage and maxNumberOfEventsPerStage.
expectedNumberOfEventsThe expected number of events under specified alternative. Is a numeric vector.
pi1The assumed event rate in the treatment group. Is a numeric vector of length kMax containing values between 0 and 1.
pi2The assumed event rate in the control group. Is a numeric vector of length 1 containing a value between 0 and 1.
median1The assumed median survival time in the treatment group. Is a numeric vector.
median2The assumed median survival time in the reference group. Is a numeric vector of length 1.
maxNumberOfSubjectsThe maximum number of subjects for power calculations. Is a numeric vector.
accrualTimeThe assumed accrual time intervals for the study. Is a numeric vector.
accrualIntensityThe absolute accrual intensities. Is a numeric vector of length kMax.
dropoutRate1The assumed drop-out rate in the treatment group. Is a numeric vector of length 1 containing a value between 0 and 1.
dropoutRate2The assumed drop-out rate in the control group. Is a numeric vector of length 1 containing a value between 0 and 1.
dropoutTimeThe assumed time for drop-out rates in the control and treatment group. Is a numeric vector of length 1.
eventTimeThe assumed time under which the event rates are calculated. Is a numeric vector of length 1.
thetaH0The difference or assumed effect under H0. Is a numeric vector of length 1.
allocation1The number of subjects to be assigned to treatment 1 in subsequent order. Is a numeric vector of length 1 containing a whole number.
allocation2The number of subjects to be assigned to treatment 2 in subsequent order. Is a numeric vector of length 1 containing a whole number.
kappaThe shape of the Weibull distribution if kappa!=1. Is a numeric vector of length 1.
piecewiseSurvivalTimeThe time intervals for the piecewise definition of the exponential survival time cumulative distribution function. Is a numeric vector.
lambda1The assumed hazard rate in the treatment group. Is a numeric vector of length kMax.
lambda2The assumed hazard rate in the reference group. Is a numeric vector of length 1.
earlyStopThe probability to stopping the trial either for efficacy or futility. Is a numeric vector.
hazardRatioThe hazard ratios under consideration. Is a numeric vector of length kMax.
studyDurationThe study duration for specified effect size. Is a positive numeric vector.
eventsNotAchievedThe simulated number of cases how often the number of events was not reached. Is a numeric matrix.
numberOfSubjectsIn simulation results data set: The number of subjects under consideration when the interim analysis takes place.
numberOfSubjects1In simulation results data set: The number of subjects under consideration in treatment arm 1 when the interim analysis takes place.
numberOfSubjects2In simulation results data set: The number of subjects under consideration in treatment arm 2 when the interim analysis takes place.
singleEventsPerStageThe single number of events per stage. Is a numeric matrix.
cumulativeEventsPerStageThe cumulative number of events per stage. Is a numeric matrix.
expectedNumberOfSubjectsThe expected number of subjects under specified alternative.
rejectPerStageThe probability to reject a hypothesis per stage of the trial. Is a numeric matrix.
overallRejectThe overall rejection probability. Is a numeric vector.
conditionalPowerAchievedThe calculated conditional power, under the assumption of observed or assumed effect sizes. Is a numeric matrix.
Use getSimulationSurvival()
to create an object of this type.
SimulationResultsSurvival is the basic class for
SimulationResultsSurvival,
SimulationResultsMultiArmSurvival, and
SimulationResultsEnrichmentSurvival.