Class for stage results of means.
stagesThe stage numbers of the trial. Is an integer vector of length kMax.
testStatisticsThe stage-wise test statistics. Is a numeric vector of length kMax.
overallTestStatisticsThe overall i.e. cumulated test statistics. Is a numeric vector of length kMax.
pValuesThe stage-wise p-values. Is a numeric vector of length kMax.
overallPValuesThe overall i.e. cumulated p-values. Is a numeric vector of length kMax.
combInverseNormalThe stage-wise test statistics for the inverse normal test. Is a numeric vector of length kMax.
combFisherTest statistic for Fisher's combination test. H~0~
effectSizesThe stage-wise effect sizes. Is a numeric vector of length kMax.
testActionsThe action drawn from test result.
weightsFisherThe weights for Fisher's combination test. Is a numeric vector of length kMax.
weightsFisherThe weights for inverse normal statistic.. Is a numeric vector of length kMax.
normalApproximationLogical. Describes if a normal approximation was used when calculating p-values.
Default for means is FALSE and TRUE for rates and hazard ratio.
equalVariancesLogical. Describes if variances are assumed equal between groups.
Specified via equalVariances in getStageResults(), default is TRUE.
This object cannot be created directly; use getStageResults()
with suitable arguments to create the stage results of a dataset of means.