printCitation: Print Citation
Description
How to cite rpact and R in publications.
Usage
printCitation(inclusiveR = TRUE, language = "en")
Arguments
- inclusiveR
If TRUE (default) the information on how to cite the base R system in publications will be added.
- language
Language code to use for the output, default is "en".
Details
This function shows how to cite rpact and R (inclusiveR = TRUE) in publications.